==> blaze-persistence-core-impl-1.0.1-sources.jar: com/blazebit/persistence/impl/builder/predicate/SuperExpressionLeftHandsideSubqueryPredicateBuilder.java <==
/*
 * Copyright 2014 Blazebit.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.blazebit.persistence.impl.builder.predicate;

import com.blazebit.persistence.impl.builder.expression.SuperExpressionSubqueryBuilderListener;
import com.blazebit.persistence.impl.SubqueryBuilderImpl;
import com.blazebit.persistence.impl.builder.predicate.LeftHandsideSubqueryPredicateBuilder;
import com.blazebit.persistence.impl.expression.Expression;

/**
 *
 * @author Moritz Becker
 * @since 1.0
 */
public class SuperExpressionLeftHandsideSubqueryPredicateBuilder<T extends LeftHandsideSubqueryPredicateBuilder> extends SuperExpressionSubqueryBuilderListener<T> {

    public SuperExpressionLeftHandsideSubqueryPredicateBuilder(String subqueryAlias, Expression superExpression) {
        super(subqueryAlias, superExpression);
    }

    @Override
    public void onBuilderEnded(SubqueryBuilderImpl<T> builder) {
        super.onBuilderEnded(builder);
        LeftHandsideSubqueryPredicateBuilder leftHandsideSubqueryPredicateBuilder =  (LeftHandsideSubqueryPredicateBuilder) builder.getResult();
        leftHandsideSubqueryPredicateBuilder.setLeftExpression(superExpression);
    }
}

==> blaze-persistence-core-impl-1.5.0-sources.jar: com/blazebit/persistence/impl/builder/predicate/SuperExpressionLeftHandsideSubqueryPredicateBuilder.java <==
/*
 * Copyright 2014 - 2020 Blazebit.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.blazebit.persistence.impl.builder.predicate;

import com.blazebit.persistence.impl.SubqueryInternalBuilder;
import com.blazebit.persistence.impl.builder.expression.SuperExpressionSubqueryBuilderListener;
import com.blazebit.persistence.parser.expression.Expression;

/**
 *
 * @author Moritz Becker
 * @since 1.0.0
 */
public class SuperExpressionLeftHandsideSubqueryPredicateBuilder<T extends LeftHandsideSubqueryPredicateBuilder> extends SuperExpressionSubqueryBuilderListener<T> {

    public SuperExpressionLeftHandsideSubqueryPredicateBuilder(String subqueryAlias, Expression superExpression) {
        super(subqueryAlias, superExpression);
    }

    @Override
    public void onBuilderEnded(SubqueryInternalBuilder<T> builder) {
        super.onBuilderEnded(builder);
        LeftHandsideSubqueryPredicateBuilder leftHandsideSubqueryPredicateBuilder = (LeftHandsideSubqueryPredicateBuilder) builder.getResult();
        leftHandsideSubqueryPredicateBuilder.setLeftExpression(superExpression);
    }
}
